==> rvkstat_3.0.0.tar.gz: rvkstat/NEWS.md <==
# 3.0.0

Дата релиза: 2021-01-14

Большое обновление пакета, которое коснулось совершенно всех функций:

* Пакет переведён на работу с API Вконтакте версии 5.126
* В пакет теперь вшито приложение для работы с API Вконтакте, но вы по прежнему можете использовать созданные вами приложения.
* Функция `vkAuth()` теперь может кешировать полученные учётные данные в локальный файл. Т.е. теперь нет необходимости хранить токены в виде текста в коде.
* Пакет поддерживает опции и переменные среды для определеня пользователя, аккаунта, агентского аккаунта, версии API, токена, пути к учётным данным, id приложения для работы с API. 
* В пакет добавлено семейство функций `vkSet*()`, которые упрощают установку опций пакета.
* В `rvkstat` был добавлен логгер, на данный момент он выводит не так много информации, но в будущем будет более функционален, управлять уровнем детализации можно с помощью функции `vkSetThreshold()`.
* У всех функций 4 последние аргумента теперь: `username`, `api_version`, `token_path`, `access_token`. При этом нет необходимости указывать версию API и токен. Лучшей практикой считается задать с помощью опций `rvkstat.username` и `rvkstat.token_path` логин пользователя под которым вы прошли авторизацию, и путь к папаке в которой хранятся учётные данные.
* В функции `vkGetAdCategories()` появился дополнительный аргумент `version`, который позволяет указать какую версию справочника вы хотите получить, указав `v1` вы получите справочник категорий с включающий устаревшие тематики, указав `v2` вы получите справочник включающий только актуальные категории.
* Изменился набор аргументов и результат в функциях: `vkGetGroupStatGenderAge()`.
* Большинство функций не именило свой интерфейс, но при этом мог изменится итоговый результат который возвращает функция, это связанно с изменениями которые были внедрены ща последний год в API Вконтакте.
* Из пакета была удалена функция `vkGetUserDialogs()` в связи с тем, что она использовала утаревший метод API, работа которого боле ене поддерживается. 
* Во всех функциях был оптимизирован процесс парсинга результата, он был полностью переписан с циклов на функции `unnest_longer()` и `unnest_wider()` из пакета `tidyr`. Это добавило пакету дополнительные зависимости, но оптимизировало скорость парсинга результата.
* Из пакета удалена устаревшая зависимость с пакетом `RCurl`, который использовался в самых ранних функциях пакета. Теперь во всех функциях для отправки запросов используется пакет `httr`.
* В функциях из семейства `vkGetGroupStat*()` добавлено 2 новые аргумента: `interval`, `intervals_count`. Данные аргументы позволяют запрашивать данные за условный период.
* В документацию по каждой функции добавлен блок references, с ссылкой на документацию по API методу который лежит в основе функции.

---

# 2.6.1

Дата релиза: 2019-12-11

Доработана основная функция для загрузки статистики рекламны `vkGetAdStatistics()`:

* В результате который вы получаете с помощью данной функции добавлено поле lead_form_sends, количество полученных лид форм по вашей рекламе.
* Увеличена пауза между отправляемыми запросами т.к. Вконтакте усилил лимиты на количество отправляемых в API запросов.

==> rvkstat_3.0.1.tar.gz: rvkstat/NEWS.md <==
# 3.0.1

Дата релиза: 2021-04-01

Исправил ошибку `Unknown or uninitialised column: `cpc`.` возникавшую при использовании функции `vkGetAds()`.

# 3.0.0

Дата релиза: 2021-01-14

Большое обновление пакета, которое коснулось совершенно всех функций:

* Пакет переведён на работу с API Вконтакте версии 5.126
* В пакет теперь вшито приложение для работы с API Вконтакте, но вы по прежнему можете использовать созданные вами приложения.
* Функция `vkAuth()` теперь может кешировать полученные учётные данные в локальный файл. Т.е. теперь нет необходимости хранить токены в виде текста в коде.
* Пакет поддерживает опции и переменные среды для определеня пользователя, аккаунта, агентского аккаунта, версии API, токена, пути к учётным данным, id приложения для работы с API. 
* В пакет добавлено семейство функций `vkSet*()`, которые упрощают установку опций пакета.
* В `rvkstat` был добавлен логгер, на данный момент он выводит не так много информации, но в будущем будет более функционален, управлять уровнем детализации можно с помощью функции `vkSetThreshold()`.
* У всех функций 4 последние аргумента теперь: `username`, `api_version`, `token_path`, `access_token`. При этом нет необходимости указывать версию API и токен. Лучшей практикой считается задать с помощью опций `rvkstat.username` и `rvkstat.token_path` логин пользователя под которым вы прошли авторизацию, и путь к папаке в которой хранятся учётные данные.
* В функции `vkGetAdCategories()` появился дополнительный аргумент `version`, который позволяет указать какую версию справочника вы хотите получить, указав `v1` вы получите справочник категорий с включающий устаревшие тематики, указав `v2` вы получите справочник включающий только актуальные категории.
* Изменился набор аргументов и результат в функциях: `vkGetGroupStatGenderAge()`.
* Большинство функций не именило свой интерфейс, но при этом мог изменится итоговый результат который возвращает функция, это связанно с изменениями которые были внедрены ща последний год в API Вконтакте.
* Из пакета была удалена функция `vkGetUserDialogs()` в связи с тем, что она использовала утаревший метод API, работа которого боле ене поддерживается. 
* Во всех функциях был оптимизирован процесс парсинга результата, он был полностью переписан с циклов на функции `unnest_longer()` и `unnest_wider()` из пакета `tidyr`. Это добавило пакету дополнительные зависимости, но оптимизировало скорость парсинга результата.
* Из пакета удалена устаревшая зависимость с пакетом `RCurl`, который использовался в самых ранних функциях пакета. Теперь во всех функциях для отправки запросов используется пакет `httr`.
* В функциях из семейства `vkGetGroupStat*()` добавлено 2 новые аргумента: `interval`, `intervals_count`. Данные аргументы позволяют запрашивать данные за условный период.
* В документацию по каждой функции добавлен блок references, с ссылкой на документацию по API методу который лежит в основе функции.

---

# 2.6.1

Дата релиза: 2019-12-11

Доработана основная функция для загрузки статистики рекламны `vkGetAdStatistics()`:

* В результате который вы получаете с помощью данной функции добавлено поле lead_form_sends, количество полученных лид форм по вашей рекламе.
* Увеличена пауза между отправляемыми запросами т.к. Вконтакте усилил лимиты на количество отправляемых в API запросов.
